@@ -2,7 +2,7 @@
 // daytime_server.cpp
 // ~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2016 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2019 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -26,16 +26,16 @@ int main()
 {
   try
   {
-    asio::io_service io_service;
+    asio::io_context io_context;
 
     tcp::endpoint endpoint(tcp::v4(), 13);
-    tcp::acceptor acceptor(io_service, endpoint);
+    tcp::acceptor acceptor(io_context, endpoint);
 
     for (;;)
     {
       tcp::iostream stream;
       asio::error_code ec;
-      acceptor.accept(*stream.rdbuf(), ec);
+      acceptor.accept(stream.socket(), ec);
       if (!ec)
       {
         stream << make_daytime_string();
