@@ -2,22 +2,23 @@
 // async_tcp_client.cpp
 // ~~~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2016 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2019 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 //
 
-#include "asio/deadline_timer.hpp"
-#include "asio/io_service.hpp"
+#include "asio/buffer.hpp"
+#include "asio/io_context.hpp"
 #include "asio/ip/tcp.hpp"
 #include "asio/read_until.hpp"
-#include "asio/streambuf.hpp"
+#include "asio/steady_timer.hpp"
 #include "asio/write.hpp"
 #include <boost/bind.hpp>
 #include <iostream>
+#include <string>
 
-using asio::deadline_timer;
+using asio::steady_timer;
 using asio::ip::tcp;
 
 //
@@ -78,25 +79,26 @@ using asio::ip::tcp;
 //
 // The heartbeat actor sends a heartbeat (a message that consists of a single
 // newline character) every 10 seconds. In this example, no deadline is applied
-// message sending.
+// to message sending.
 //
 class client
 {
 public:
-  client(asio::io_service& io_service)
+  client(asio::io_context& io_context)
     : stopped_(false),
-      socket_(io_service),
-      deadline_(io_service),
-      heartbeat_timer_(io_service)
+      socket_(io_context),
+      deadline_(io_context),
+      heartbeat_timer_(io_context)
   {
   }
 
   // Called by the user of the client class to initiate the connection process.
-  // The endpoint iterator will have been obtained using a tcp::resolver.
-  void start(tcp::resolver::iterator endpoint_iter)
+  // The endpoints will have been obtained using a tcp::resolver.
+  void start(tcp::resolver::results_type endpoints)
   {
     // Start the connect actor.
-    start_connect(endpoint_iter);
+    endpoints_ = endpoints;
+    start_connect(endpoints_.begin());
 
     // Start the deadline actor. You will note that we're not setting any
     // particular deadline here. Instead, the connect and input actors will
@@ -117,14 +119,14 @@ public:
   }
 
 private:
-  void start_connect(tcp::resolver::iterator endpoint_iter)
+  void start_connect(tcp::resolver::results_type::iterator endpoint_iter)
   {
-    if (endpoint_iter != tcp::resolver::iterator())
+    if (endpoint_iter != endpoints_.end())
     {
       std::cout << "Trying " << endpoint_iter->endpoint() << "...\n";
 
       // Set a deadline for the connect operation.
-      deadline_.expires_from_now(boost::posix_time::seconds(60));
+      deadline_.expires_after(asio::chrono::seconds(60));
 
       // Start the asynchronous connect operation.
       socket_.async_connect(endpoint_iter->endpoint(),
@@ -139,7 +141,7 @@ private:
   }
 
   void handle_connect(const asio::error_code& ec,
-      tcp::resolver::iterator endpoint_iter)
+      tcp::resolver::results_type::iterator endpoint_iter)
   {
     if (stopped_)
       return;
@@ -184,14 +186,15 @@ private:
   void start_read()
   {
     // Set a deadline for the read operation.
-    deadline_.expires_from_now(boost::posix_time::seconds(30));
+    deadline_.expires_after(asio::chrono::seconds(30));
 
     // Start an asynchronous operation to read a newline-delimited message.
-    asio::async_read_until(socket_, input_buffer_, '\n',
-        boost::bind(&client::handle_read, this, _1));
+    asio::async_read_until(socket_,
+        asio::dynamic_buffer(input_buffer_), '\n',
+        boost::bind(&client::handle_read, this, _1, _2));
   }
 
-  void handle_read(const asio::error_code& ec)
+  void handle_read(const asio::error_code& ec, std::size_t n)
   {
     if (stopped_)
       return;
@@ -199,9 +202,8 @@ private:
     if (!ec)
     {
       // Extract the newline-delimited message from the buffer.
-      std::string line;
-      std::istream is(&input_buffer_);
-      std::getline(is, line);
+      std::string line(input_buffer_.substr(0, n - 1));
+      input_buffer_.erase(0, n);
 
       // Empty messages are heartbeats and so ignored.
       if (!line.empty())
@@ -237,7 +239,7 @@ private:
     if (!ec)
     {
       // Wait 10 seconds before sending the next heartbeat.
-      heartbeat_timer_.expires_from_now(boost::posix_time::seconds(10));
+      heartbeat_timer_.expires_after(asio::chrono::seconds(10));
       heartbeat_timer_.async_wait(boost::bind(&client::start_write, this));
     }
     else
@@ -256,15 +258,16 @@ private:
     // Check whether the deadline has passed. We compare the deadline against
     // the current time since a new asynchronous operation may have moved the
     // deadline before this actor had a chance to run.
-    if (deadline_.expires_at() <= deadline_timer::traits_type::now())
+    if (deadline_.expiry() <= steady_timer::clock_type::now())
     {
       // The deadline has passed. The socket is closed so that any outstanding
       // asynchronous operations are cancelled.
       socket_.close();
 
-      // There is no longer an active deadline. The expiry is set to positive
-      // infinity so that the actor takes no action until a new deadline is set.
-      deadline_.expires_at(boost::posix_time::pos_infin);
+      // There is no longer an active deadline. The expiry is set to the
+      // maximum time point so that the actor takes no action until a new
+      // deadline is set.
+      deadline_.expires_at(steady_timer::time_point::max());
     }
 
     // Put the actor back to sleep.
@@ -273,10 +276,11 @@ private:
 
 private:
   bool stopped_;
+  tcp::resolver::results_type endpoints_;
   tcp::socket socket_;
-  asio::streambuf input_buffer_;
-  deadline_timer deadline_;
-  deadline_timer heartbeat_timer_;
+  std::string input_buffer_;
+  steady_timer deadline_;
+  steady_timer heartbeat_timer_;
 };
 
 int main(int argc, char* argv[])
@@ -289,13 +293,13 @@ int main(int argc, char* argv[])
       return 1;
     }
 
-    asio::io_service io_service;
-    tcp::resolver r(io_service);
-    client c(io_service);
+    asio::io_context io_context;
+    tcp::resolver r(io_context);
+    client c(io_context);
 
-    c.start(r.resolve(tcp::resolver::query(argv[1], argv[2])));
+    c.start(r.resolve(argv[1], argv[2]));
 
-    io_service.run();
+    io_context.run();
   }
   catch (std::exception& e)
   {
