@@ -2,7 +2,7 @@
 // datagram_protocol.cpp
 // ~~~~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2016 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2019 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -17,7 +17,7 @@
 #include "asio/local/datagram_protocol.hpp"
 
 #include <cstring>
-#include "asio/io_service.hpp"
+#include "asio/io_context.hpp"
 #include "../unit_test.hpp"
 
 //------------------------------------------------------------------------------
@@ -51,7 +51,8 @@ void test()
 
   try
   {
-    io_service ios;
+    io_context ioc;
+    const io_context::executor_type ioc_ex = ioc.get_executor();
     char mutable_char_buffer[128] = "";
     const char const_char_buffer[128] = "";
     socket_base::message_flags in_flags = 0;
@@ -61,16 +62,22 @@ void test()
 
     // basic_datagram_socket constructors.
 
-    dp::socket socket1(ios);
-    dp::socket socket2(ios, dp());
-    dp::socket socket3(ios, dp::endpoint(""));
+    dp::socket socket1(ioc);
+    dp::socket socket2(ioc, dp());
+    dp::socket socket3(ioc, dp::endpoint(""));
     int native_socket1 = ::socket(AF_UNIX, SOCK_DGRAM, 0);
-    dp::socket socket4(ios, dp(), native_socket1);
+    dp::socket socket4(ioc, dp(), native_socket1);
+
+    dp::socket socket5(ioc_ex);
+    dp::socket socket6(ioc_ex, dp());
+    dp::socket socket7(ioc_ex, dp::endpoint(""));
+    int native_socket2 = ::socket(AF_UNIX, SOCK_DGRAM, 0);
+    dp::socket socket8(ioc_ex, dp(), native_socket2);
 
     // basic_io_object functions.
 
-    io_service& ios_ref = socket1.get_io_service();
-    (void)ios_ref;
+    dp::socket::executor_type ex = socket1.get_executor();
+    (void)ex;
 
     // basic_socket functions.
 
@@ -80,10 +87,10 @@ void test()
     socket1.open(dp());
     socket1.open(dp(), ec);
 
-    int native_socket2 = ::socket(AF_UNIX, SOCK_DGRAM, 0);
-    socket1.assign(dp(), native_socket2);
     int native_socket3 = ::socket(AF_UNIX, SOCK_DGRAM, 0);
-    socket1.assign(dp(), native_socket3, ec);
+    socket1.assign(dp(), native_socket3);
+    int native_socket4 = ::socket(AF_UNIX, SOCK_DGRAM, 0);
+    socket1.assign(dp(), native_socket4, ec);
 
     bool is_open = socket1.is_open();
     (void)is_open;
@@ -91,8 +98,8 @@ void test()
     socket1.close();
     socket1.close(ec);
 
-    dp::socket::native_type native_socket4 = socket1.native();
-    (void)native_socket4;
+    dp::socket::native_handle_type native_socket5 = socket1.native_handle();
+    (void)native_socket5;
 
     socket1.cancel();
     socket1.cancel(ec);
@@ -125,10 +132,14 @@ void test()
     socket1.io_control(io_control_command, ec);
 
     dp::endpoint endpoint1 = socket1.local_endpoint();
+    (void)endpoint1;
     dp::endpoint endpoint2 = socket1.local_endpoint(ec);
+    (void)endpoint2;
 
     dp::endpoint endpoint3 = socket1.remote_endpoint();
+    (void)endpoint3;
     dp::endpoint endpoint4 = socket1.remote_endpoint(ec);
+    (void)endpoint4;
 
     socket1.shutdown(socket_base::shutdown_both);
     socket1.shutdown(socket_base::shutdown_both, ec);
