@@ -2,7 +2,7 @@
 // socket_base.cpp
 // ~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2016 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2019 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -16,7 +16,7 @@
 // Test that header file is self-contained.
 #include "asio/socket_base.hpp"
 
-#include "asio/io_service.hpp"
+#include "asio/io_context.hpp"
 #include "asio/ip/tcp.hpp"
 #include "asio/ip/udp.hpp"
 #include "unit_test.hpp"
@@ -37,8 +37,8 @@ void test()
 
   try
   {
-    io_service ios;
-    ip::tcp::socket sock(ios);
+    io_context ioc;
+    ip::tcp::socket sock(ioc);
     char buf[1024];
 
     // shutdown_type enumeration.
@@ -155,6 +155,17 @@ void test()
     linger1.timeout(1);
     (void)static_cast<int>(linger1.timeout());
 
+    // out_of_band_inline class.
+
+    socket_base::out_of_band_inline out_of_band_inline1(true);
+    sock.set_option(out_of_band_inline1);
+    socket_base::out_of_band_inline out_of_band_inline2;
+    sock.get_option(out_of_band_inline2);
+    out_of_band_inline1 = true;
+    (void)static_cast<bool>(out_of_band_inline1);
+    (void)static_cast<bool>(!out_of_band_inline1);
+    (void)static_cast<bool>(out_of_band_inline1.value());
+
     // enable_connection_aborted class.
 
     socket_base::enable_connection_aborted enable_connection_aborted1(true);
@@ -166,11 +177,6 @@ void test()
     (void)static_cast<bool>(!enable_connection_aborted1);
     (void)static_cast<bool>(enable_connection_aborted1.value());
 
-    // non_blocking_io class.
-
-    socket_base::non_blocking_io non_blocking_io(true);
-    sock.io_control(non_blocking_io);
-
     // bytes_readable class.
 
     socket_base::bytes_readable bytes_readable;
@@ -199,10 +205,10 @@ void test()
   using namespace asio;
   namespace ip = asio::ip;
 
-  io_service ios;
-  ip::udp::socket udp_sock(ios, ip::udp::v4());
-  ip::tcp::socket tcp_sock(ios, ip::tcp::v4());
-  ip::tcp::acceptor tcp_acceptor(ios, ip::tcp::v4());
+  io_context ioc;
+  ip::udp::socket udp_sock(ioc, ip::udp::v4());
+  ip::tcp::socket tcp_sock(ioc, ip::tcp::v4());
+  ip::tcp::acceptor tcp_acceptor(ioc, ip::tcp::v4());
   asio::error_code ec;
 
   // broadcast class.
@@ -625,16 +631,6 @@ void test()
   ASIO_CHECK(!static_cast<bool>(enable_connection_aborted4));
   ASIO_CHECK(!enable_connection_aborted4);
 
-  // non_blocking_io class.
-
-  socket_base::non_blocking_io non_blocking_io1(true);
-  tcp_sock.io_control(non_blocking_io1, ec);
-  ASIO_CHECK_MESSAGE(!ec, ec.value() << ", " << ec.message());
-
-  socket_base::non_blocking_io non_blocking_io2(false);
-  tcp_sock.io_control(non_blocking_io2, ec);
-  ASIO_CHECK_MESSAGE(!ec, ec.value() << ", " << ec.message());
-
   // bytes_readable class.
 
   socket_base::bytes_readable bytes_readable;
